@@ -21,5 +21,5 @@ for i in apend.runcom archiv.runcom xpand.runcom squash.runcom \
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>arc_ext.dat
 done
-cat EOF.BIN >>arc_src.bcd
+#cat EOF.BIN >>arc_src.bcd
 rm tmp.img
