@@ -2,7 +2,7 @@ USER=' M1416    21'
 echo -n > asclib_src.bcd
 for i in nsctss.fap ; do
      NAME=`basename $i .fap`
-     obj2img -A -a "$USER" -t -f $NAME -e 'FAP' -o tmp.img $i
+     obj2img -A -a "$USER" -t -c -f $NAME -e 'FAP' -o tmp.img $i
      cat tmp.img >> asclib_src.bcd
 done
 for i in ascon.mad asctyp.mad edval.mad escape.mad getdev.mad ncanno.mad \
@@ -17,5 +17,5 @@ grep '(LIST)' asclib.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >asc_ext.dat
 grep '(LIST)' asclib.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BSS     B'"$USER"'"}' >asc_bss.dat
-cat EOF.BIN >>asclib_src.bcd
+#cat EOF.BIN >>asclib_src.bcd
 rm tmp.img
