@@ -23,5 +23,5 @@ for i in madbug.runcom ; do
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>bug_ext.dat
 done
-cat EOF.BIN >>bug_src.bcd
+#cat EOF.BIN >>bug_src.bcd
 rm tmp.img
