@@ -6,7 +6,7 @@ for i in 0qed.fap 1qed.fap 2qed.fap asctss.fap bin.fap clrnam.fap cnvtbl.fap dev
 	prnter.fap prword.fap qed.fap rename.fap setops.fap setup.fap unpnr.fap wordio.fap \
 	zcmd.fap wmacs.fap prer.fap ; do
      NAME=`basename $i .fap | sed 's/_/./g'`
-     obj2img -A -a "$USER" -t -f $NAME -e 'FAP' -o tmp.img $i
+     obj2img -A -a "$USER" -t -c -f $NAME -e 'FAP' -o tmp.img $i
      cat tmp.img >> edt_src.bcd
 done
 for i in 12typ.mad 6concd.mad 6typ.mad bincon.mad binval.mad edaval.mad editcd.mad \
@@ -23,5 +23,5 @@ for i in  eda.runcom edb.runcom edc.runcom edl.runcom p.runcom typset.runcom \
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>edt_ext.dat
 done
-cat EOF.BIN >>edt_src.bcd
+#cat EOF.BIN >>edt_src.bcd
 rm tmp.img
