@@ -16,5 +16,5 @@ done
 obj2img -A -a "$USER" -t -f edit -e 'RUNCOM' -o tmp.img edit.runcom
 cat tmp.img >> edit_src.bcd
 awk '{x="      " $1; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' edit.dat >edt_ext.dat
-cat EOF.BIN >>edit_src.bcd
+#cat EOF.BIN >>edit_src.bcd
 rm tmp.img
