@@ -14,6 +14,5 @@ for i in delfib.runcom fibmon.runcom fib.runcom prfib.runcom \
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>fib_ext.dat
 done
-cat tmp.img >> fib_src.bcd
-cat EOF.BIN >>fib_src.bcd
+#cat EOF.BIN >>fib_src.bcd
 rm tmp.img
