@@ -15,9 +15,5 @@ obj2img -A -a "$USER" -t -f filsim -e 'RUNCOM' -o tmp.img filsim.runcom
 cat tmp.img >> filsim_src.bcd
 obj2img -A -a "$USER" -t -f salsim -e 'RUNCOM' -o tmp.img salsim.runcom
 cat tmp.img >> filsim_src.bcd
-cat EOF.BIN >>filsim_src.bcd
+#cat EOF.BIN >>filsim_src.bcd
 rm tmp.img
-grep '(LIST)' filsim.runcom \
-	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >fil_ext.dat
-grep '(LIST)' salsim.runcom \
-	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >sal_ext.dat
