@@ -14,9 +14,5 @@ obj2img -A -a "$USER" -t -f fsb -e 'RUNCOM' -o tmp.img fsb.runcom
 cat tmp.img >> fsb_src.bcd
 obj2img -A -a "$USER" -t -f fsa -e 'RUNCOM' -o tmp.img fsa.runcom
 cat tmp.img >> fsb_src.bcd
-cat EOF.BIN >>fsb_src.bcd
+#cat EOF.BIN >>fsb_src.bcd
 rm tmp.img
-grep '(LIST)' fsa.runcom \
-	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >fsa_ext.dat
-grep '(LIST)' fsb.runcom \
-	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >fsb_ext.dat
