@@ -11,6 +11,11 @@ for i in iop9.mad mfns.mad mrrp.mad mtr2.mad mtrn.mad tdfev.mad ; do
      obj2img -A -a "$USER" -t -c -f $NAME -e 'MAD' -o tmp.img $i
      cat tmp.img >> mad_src.bcd
 done
+for i in primes.f ; do
+     NAME=`basename $i .f | sed 's/_/./g'`
+     obj2img -A -a "$USER" -t -f $NAME -e 'MADTRN' -o tmp.img $i
+     cat tmp.img >> mad_src.bcd
+done
 for i in madtrn.runcom ; do
      NAME=`basename $i .runcom | sed 's/_/./g'`
      obj2img -A -a "$USER" -t -f $NAME -e 'RUNCOM' -o tmp.img $i
@@ -18,5 +23,5 @@ for i in madtrn.runcom ; do
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>mad_ext.dat
 done
-cat EOF.BIN >>mad_src.bcd
+#cat EOF.BIN >>mad_src.bcd
 rm tmp.img
