@@ -2,7 +2,7 @@ USER=' M1416    30'
 echo -n > mit_src.bcd
 echo -n > mit_ext.dat
 for i in adpi8a.fap ap758a.fap bksv8c.fap brkp8d.fap chne8a.fap cloc8h.fap com800.fap \
-	comc8g.fap common.fap conv8a.fap cpyc8b.fap crtl8f.fap dump8b.fap edbg8a.fap \
+	comc8g.fap common.fap conv8a.fap cpyc8b.fap ctrl8f.fap dump8b.fap edbg8a.fap \
 	equ.fap fint8b.fap high8a.fap ibuf8b.fap macro.fap main8c.fap onln8f.fap \
 	pdpa8b.fap pmti8a.fap rtrn8e.fap savc8c.fap savr8b.fap scda8c.fap scdb8a.fap \
 	scdc8c.fap scdd8a.fap t2char.fap tachar.fap tcor8b.fap tsto8a.fap twchar.fap \
@@ -24,5 +24,5 @@ for i in mit.runcom upd.runcom ; do
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>mit_ext.dat
 done
-cat EOF.BIN >>mit_src.bcd
+#cat EOF.BIN >>mit_src.bcd
 rm tmp.img
