@@ -21,5 +21,5 @@ grep '(LIST)' plibe.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >plib_ext.dat
 grep '(LIST)' plibe.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BSS     B'"$USER"'"}' >plib_bss.dat
-cat EOF.BIN >>plib_src.bcd
+#cat EOF.BIN >>plib_src.bcd
 rm tmp.img
