@@ -12,6 +12,8 @@ for i in adjust.mad frame1.mad hdft.mad numcon.mad nxchar.mad rmain.mad \
      obj2img -A -a "$USER" -t -c -f $NAME -e 'MAD' -o tmp.img $i
      cat tmp.img >> run_src.bcd
 done
+obj2img -A -a "$USER" -t -x -f "tmring" -e 'RUNOFF' -o tmp.img tmring.run
+cat tmp.img >> run_src.bcd
 for i in  runoff.runcom ; do
      NAME=`basename $i .runcom | sed 's/_/./g'`
      obj2img -A -a "$USER" -t -f $NAME -e 'RUNCOM' -o tmp.img $i
@@ -19,5 +21,5 @@ for i in  runoff.runcom ; do
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>run_ext.dat
 done
-cat EOF.BIN >>run_src.bcd
+#cat EOF.BIN >>run_src.bcd
 rm tmp.img
