@@ -25,5 +25,5 @@ for i in cylod.runcom dsetup.runcom panic.runcom b1inp.runcom b1prt1.runcom \
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>sutl_ext.dat
 done
-cat EOF.BIN >>sutl_src.bcd
+#cat EOF.BIN >>sutl_src.bcd
 rm tmp.img
