@@ -7,7 +7,7 @@ for i in dioi.fap diot.fap indx.fap keys.fap mprt.fap rdin.fap _rst.fap setp.fap
      obj2img -A -a "$USER" -t -f $NAME -e 'FAP' -o tmp.img $i
      cat tmp.img >> sal_src.bcd
 done
-for i in salv4.ctssld sort4a.ctssld stat4a.ctssld ; do
+for i in salv4a.ctssld sort4a.ctssld stat4a.ctssld ; do
      NAME=`basename $i .ctssld | sed 's/_/./g'`
      obj2img -A -a "$USER" -t -f $NAME -e 'CTSSLD' -o tmp.img $i
      cat tmp.img >> sal_src.bcd
@@ -26,5 +26,5 @@ for i in dump4.runcom load4.runcom salv4.runcom sort4.runcom stat4.runcom \
      grep '(LIST)' $i \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >>sal_ext.dat
 done
-cat EOF.BIN >>sal_src.bcd
+#cat EOF.BIN >>sal_src.bcd
 rm tmp.img
