@@ -24,5 +24,5 @@ grep '(LIST)' lib2.runcom | \
 	 awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >ts2_ext.dat
 grep '(LIST)' lib2.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BSS     B'"$USER"'"}' > ts2_bss.dat
-cat EOF.BIN >>lib2_src.bcd
+#cat EOF.BIN >>lib2_src.bcd
 rm tmp.img
