@@ -11,5 +11,5 @@ grep '(LIST)' tslib2.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >tsl2_ext.dat
 grep '(LIST)' tslib2.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BSS     B'"$USER"'"}' >tsl2_bss.dat
-cat EOF.BIN >>tslib2_src.bcd
+#cat EOF.BIN >>tslib2_src.bcd
 rm tmp.img
