@@ -22,5 +22,5 @@ grep '(LIST)' xlibe.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BCD     I'"$USER"'"}' >xlib_ext.dat
 grep '(LIST)' xlibe.runcom \
 	| awk '{x="      " $2; print substr(x,length(x)-5,6) "   BSS     B'"$USER"'"}' >xlib_bss.dat
-cat EOF.BIN >>xlib_src.bcd
+#cat EOF.BIN >>xlib_src.bcd
 rm tmp.img
